Reason: a GUI for yt

# yt

- home
- docs
- development page
- report a bug
- chat
- reason manual

## Reason: A GUI for yt

Reason is an interactive form of yt, totally accessible from a web browser. It has full yt capabilities, as if you are acting from the Python intepreter, yet it also provides a new way of interacting directly with your data objects. Because it is run through a web browser, you can run it remotely on HPC facilities where your data may reside, while manipulating and visualizing it in real time at your own local console.

## Using the yt console

The Reason layout consists of a yt input box as well as an output window. Whenever you press shift-enter, the contents of your input box is sent to the server and the results returned. While the server is processing, the box around the input form will turn red and become read-only. When the server has returned a result, it will return to normal and allow input.

When using the Reason window to create a plot collection object, the saved images will be returned in the window. You can click on these images to view them at full-size.

## Interactive Visualization

Once you have loaded data off disk, either by loading it in the Notebook, or choosing "Load File" from the menu, you can right click on any object in the left hand menu to choose different visualization options.

You can also supply files on the command line when starting Reason, or run with "-f" to search for them in the current directory.

## Delivering Images and Scripts

The command `deliver_image('filename.png')` will display the file `filename.png` in the output window. The command `load_script('filename.py')` will fill the execution area with the script `filename.py`.

## How to Quit

To quit, either choose "Quit" from the menu or press Ctrl-C in the console window that you ran "yt serve" within.